@@ -24,9 +24,9 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kglobal.h>
-#include <kconfig.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
 #include <kcalendarsystem.h>
 
 // ----------------------------------------------------------------------------
@@ -164,14 +164,14 @@ void MyMoneyQifProfile::clear(void)
   m_decimal['Q'] =
   m_decimal['T'] =
   m_decimal['O'] =
-  m_decimal['I'] = KGlobal::locale()->monetaryDecimalSymbol()[0];
+  m_decimal['I'] = TDEGlobal::locale()->monetaryDecimalSymbol()[0];
 
   m_thousands.clear();
   m_thousands['$'] =
   m_thousands['Q'] =
   m_thousands['T'] =
   m_thousands['O'] =
-  m_thousands['I'] = KGlobal::locale()->monetaryThousandsSeparator()[0];
+  m_thousands['I'] = TDEGlobal::locale()->monetaryThousandsSeparator()[0];
 
   m_openingBalanceText = "Opening Balance";
   m_voidMark = "VOID ";
@@ -186,7 +186,7 @@ void MyMoneyQifProfile::clear(void)
 
 void MyMoneyQifProfile::loadProfile(const TQString& name)
 {
-  KConfig* config = KGlobal::config();
+  TDEConfig* config = TDEGlobal::config();
   config->setGroup(name);
 
   clear();
@@ -232,7 +232,7 @@ void MyMoneyQifProfile::loadProfile(const TQString& name)
 void MyMoneyQifProfile::saveProfile(void)
 {
   if(m_isDirty == true) {
-    KConfig* config = KGlobal::config();
+    TDEConfig* config = TDEGlobal::config();
     config->setGroup(m_profileName);
 
     config->writeEntry("Description", m_profileDescription);
@@ -418,7 +418,7 @@ TQString MyMoneyQifProfile::date(const TQDate& datein) const
             if(delim)
               buffer += delim;
             if(maskLen == 3)
-              buffer += KGlobal::locale()->calendar()->monthName(datein.month(), datein.year(), true);
+              buffer += TDEGlobal::locale()->calendar()->monthName(datein.month(), datein.year(), true);
             else
               buffer += TQString::number(datein.month()).rightJustify(2, '0');
             break;
@@ -466,14 +466,14 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
     TQStringList monthNames = TQStringList::split(",", "jan,feb,mar,apr,may,jun,jul,aug,sep,oct,nov,dec");
     int j;
     for(j = 1; j <= 12; ++j) {
-      if((KGlobal::locale()->calendar()->monthName(j, 2000, true).lower() == scannedParts[d->m_partPos['m']].lower())
+      if((TDEGlobal::locale()->calendar()->monthName(j, 2000, true).lower() == scannedParts[d->m_partPos['m']].lower())
       || (monthNames[j-1] == scannedParts[d->m_partPos['m']].lower())) {
         mon = j;
         break;
       }
     }
     if(j == 13) {
-      qWarning("Unknown month '%s'", scannedParts[d->m_partPos['m']].data());
+      tqWarning("Unknown month '%s'", scannedParts[d->m_partPos['m']].data());
       return TQDate();
     }
   }
@@ -501,7 +501,7 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
     if(m_dateFormat[i] == '%') {
       ++part;
       if(part == 3) {
-        qWarning("MyMoneyQifProfile::date(const TQString& datein) Too many parts in date format");
+        tqWarning("MyMoneyQifProfile::date(const TQString& datein) Too many parts in date format");
         return TQDate();
       }
       ++i;
@@ -517,14 +517,14 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
       case '.':
       case '\'':
         if(delim == 2) {
-          qWarning("MyMoneyQifProfile::date(const TQString& datein) Too many delimiters in date format");
+          tqWarning("MyMoneyQifProfile::date(const TQString& datein) Too many delimiters in date format");
           return TQDate();
         }
         formatDelim[delim] = m_dateFormat[i];
         ++delim;
         break;
       default:
-        qWarning("MyMoneyQifProfile::date(const TQString& datein) Invalid char in date format");
+        tqWarning("MyMoneyQifProfile::date(const TQString& datein) Invalid char in date format");
         return TQDate();
     }
   }
@@ -540,7 +540,7 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
       case '-':
       case '\'':
         if(delim == 2) {
-          qWarning("MyMoneyQifProfile::date(const TQString& datein) Too many delimiters in date field");
+          tqWarning("MyMoneyQifProfile::date(const TQString& datein) Too many delimiters in date field");
           return TQDate();
         }
         scannedDelim[delim] = datein[i];
@@ -569,7 +569,7 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
   for(i = 0; i < 2; ++i) {
     if(scannedDelim[i] != formatDelim[i]
     && scannedDelim[i] != TQChar('\'')) {
-      qWarning("MyMoneyQifProfile::date(const TQString& datein) Invalid delimiter '%s' when '%s' was expected",
+      tqWarning("MyMoneyQifProfile::date(const TQString& datein) Invalid delimiter '%s' when '%s' was expected",
         scannedDelim[i].latin1(), formatDelim[i].latin1());
       return TQDate();
     }
@@ -590,7 +590,7 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
             msg = "Invalid numeric character in month string";
         } else {
           for(j = 1; j <= 12; ++j) {
-            if(KGlobal::locale()->calendar()->monthName(j, 2000, true).lower() == formatParts[i].lower()) {
+            if(TDEGlobal::locale()->calendar()->monthName(j, 2000, true).lower() == formatParts[i].lower()) {
               mon = j;
               ok = true;
               break;
@@ -654,7 +654,7 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
         break;
     }
     if(!msg.isEmpty()) {
-      qWarning("MyMoneyQifProfile::date(const TQString& datein) %s",msg.latin1());
+      tqWarning("MyMoneyQifProfile::date(const TQString& datein) %s",msg.latin1());
       return TQDate();
     }
   }
