@@ -14,7 +14,7 @@
  *                                                                         *
  ***************************************************************************/
 // Include internationalization
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include "mymoneyscheduletest.h"
 
