@@ -31,7 +31,7 @@
 // KDE Includes
 
 #include "kdecompat.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 
 // ----------------------------------------------------------------------------
@@ -107,31 +107,31 @@ MyMoneyXmlContentHandler::MyMoneyXmlContentHandler(MyMoneyStorageXML* reader) :
 
 bool MyMoneyXmlContentHandler::startDocument(void)
 {
-  qDebug("startDocument");
+  tqDebug("startDocument");
   return true;
 }
 
 bool MyMoneyXmlContentHandler::endDocument(void)
 {
-  qDebug("endDocument");
+  tqDebug("endDocument");
   return true;
 }
 
 bool MyMoneyXmlContentHandler::skippedEntity (const TQString & /* name */)
 {
-  // qDebug(TQString("Skipped entity '%1'").arg(name));
+  // tqDebug(TQString("Skipped entity '%1'").arg(name));
   return true;
 }
 
 bool MyMoneyXmlContentHandler::startPrefixMapping (const TQString& /*prefix */, const TQString & /* uri */)
 {
-  // qDebug(TQString("start prefix '%1', '%2'").arg(prefix).arg(uri));
+  // tqDebug(TQString("start prefix '%1', '%2'").arg(prefix).arg(uri));
   return true;
 }
 
 bool MyMoneyXmlContentHandler::endPrefixMapping (const TQString& /* prefix */)
 {
-  // qDebug(TQString("end prefix '%1'").arg(prefix));
+  // tqDebug(TQString("end prefix '%1'").arg(prefix));
   return true;
 }
 
@@ -160,35 +160,35 @@ bool MyMoneyXmlContentHandler::startElement (const TQString& /* namespaceURI */,
       m_level = 1;
 
     } else if(s == "transactions") {
-      qDebug("reading transactions");
+      tqDebug("reading transactions");
       if(atts.count()) {
         int count = atts.value(TQString("count")).toUInt();
         m_reader->signalProgress(0, count, i18n("Loading transactions..."));
         m_elementCount = 0;
       }
     } else if(s == "accounts") {
-      qDebug("reading accounts");
+      tqDebug("reading accounts");
       if(atts.count()) {
         int count = atts.value(TQString("count")).toUInt();
         m_reader->signalProgress(0, count, i18n("Loading accounts..."));
         m_elementCount = 0;
       }
     } else if(s == "securities") {
-      qDebug("reading securities");
+      tqDebug("reading securities");
       if(atts.count()) {
         int count = atts.value(TQString("count")).toUInt();
         m_reader->signalProgress(0, count, i18n("Loading securities..."));
         m_elementCount = 0;
       }
     } else if(s == "reports") {
-      qDebug("reading reports");
+      tqDebug("reading reports");
       if(atts.count()) {
         int count = atts.value(TQString("count")).toUInt();
         m_reader->signalProgress(0, count, i18n("Loading reports..."));
         m_elementCount = 0;
       }
     } else if(s == "prices") {
-      qDebug("reading prices");
+      tqDebug("reading prices");
       m_elementCount = 0;
     } else if(s == "pricepair") {
       if(atts.count()) {
@@ -375,17 +375,17 @@ MyMoneyStorageXML::~MyMoneyStorageXML()
 // Function to read in the file, send to XML parser.
 void MyMoneyStorageXML::readFile(TQIODevice* pDevice, IMyMoneySerialize* storage)
 {
-  Q_CHECK_PTR(storage);
-  Q_CHECK_PTR(pDevice);
+  TQ_CHECK_PTR(storage);
+  TQ_CHECK_PTR(pDevice);
   if(!storage)
     return;
 
   m_storage = storage;
 
   m_doc = new TQDomDocument;
-  Q_CHECK_PTR(m_doc);
+  TQ_CHECK_PTR(m_doc);
 
-  qDebug("reading file");
+  tqDebug("reading file");
   // creating the TQXmlInputSource object based on a TQIODevice object
   // reads all data of the underlying object into memory. I have not
   // found an object that reads on the fly. I tried to derive one myself,
@@ -393,7 +393,7 @@ void MyMoneyStorageXML::readFile(TQIODevice* pDevice, IMyMoneySerialize* storage
   // blocks of data and not a stream. So I left it the way it is. (ipwizard)
   TQXmlInputSource xml(pDevice);
 
-  qDebug("start parsing file");
+  tqDebug("start parsing file");
   MyMoneyXmlContentHandler mmxml(this);
   TQXmlSimpleReader reader;
   reader.setContentHandler(&mmxml);
@@ -423,17 +423,17 @@ void MyMoneyStorageXML::readFile(TQIODevice* pDevice, IMyMoneySerialize* storage
 
 void MyMoneyStorageXML::writeFile(TQIODevice* qf, IMyMoneySerialize* storage)
 {
-  Q_CHECK_PTR(qf);
-  Q_CHECK_PTR(storage);
+  TQ_CHECK_PTR(qf);
+  TQ_CHECK_PTR(storage);
   if(!storage)
   {
     return;
   }
   m_storage = storage;
 
-  // qDebug("XMLWRITER: Starting file write");
+  // tqDebug("XMLWRITER: Starting file write");
   m_doc = new TQDomDocument("KMYMONEY-FILE");
-  Q_CHECK_PTR(m_doc);
+  TQ_CHECK_PTR(m_doc);
   TQDomProcessingInstruction instruct = m_doc->createProcessingInstruction("xml", "version=\"1.0\" encoding=\"utf-8\"");
   m_doc->appendChild(instruct);
 
